# CRYSTALClear 💎 

## Description 📄

A python framework for the [CRYSTAL](https://www.crystal.unito.it) code. Forked from [CRYSTALpytools](https://github.com/crystal-code-tools/CRYSTALpytools).

## Table of Contents 📑

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

## Features ✨
- Band structure and DOSS
- Elastic properties (Young and shear moduli, linear compressibility, Poisson ratio) 
- Harmonic and anharmonic IR and Raman spectra
## Installation 💻
Public releases of the code are distributed through Pypi.
### Prerequisites 📦
The following will be installed if not already present:
- Python 3.x
- pymatgen>=2022
- numpy
- mendeleev
- ase
### Steps 🛠️

1. Create a conda environment (suggested)
	```sh
	conda create --name crystalclear python=3.9		
	```
2. Activate the environment (suggested)
    ```sh
    conda activate crystalclear
    ```
3. Install
    ```sh
    pip install CRYSTALClear
    ```

## Usage 🚀
TO BE POPULATED 

## Contributing 🤝
Contributions are what make the open source community such an amazing place to be, learn, inspire, and create. Any contributions you make are  **greatly appreciated**.
1.  Fork the Project
2.  Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3.  Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4.  Push to the Branch (`git push origin feature/AmazingFeature`)
5.  Open a Pull Request

## License 📜
Distributed under the  `MIT`  License. See  `LICENSE.txt`  for more information.

## Contact 📬
- Website: https://www.crystal.unito.it
- Email: crystalunito@gmail.com
- Instagram:  [@crystaldevs](https://www.instagram.com/crystaldevs/)

